summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/autolayout/graphvizgraph.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/autolayout/graphvizgraph.cpp')
-rw-r--r--umbrello/umbrello/autolayout/graphvizgraph.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/umbrello/umbrello/autolayout/graphvizgraph.cpp b/umbrello/umbrello/autolayout/graphvizgraph.cpp
index 716f9223..a3b4ea8a 100644
--- a/umbrello/umbrello/autolayout/graphvizgraph.cpp
+++ b/umbrello/umbrello/autolayout/graphvizgraph.cpp
@@ -23,7 +23,7 @@ char* _strcpy(const char* name)
a=strcpy(a,name);
return a;
}
-namespace Autolayout
+namespace Autotqlayout
{
/**
@@ -31,7 +31,7 @@ namespace Autolayout
* @return
*/
GraphvizGraph::GraphvizGraph()
- : Autolayout::Graph()
+ : Autotqlayout::Graph()
{
aginit();
empty_flag=true;
@@ -42,7 +42,7 @@ GraphvizGraph::GraphvizGraph()
a_weight= agedgeattr(_agraph,"weight","");
agnodeattr(_agraph, "fixedsize", "true");
agnodeattr(_agraph, "margin", "0.01,0.01");
- agnodeattr(_agraph, "shape", "box");
+ agnodeattr(_agraph, "tqshape", "box");
agraphattr(_agraph, "dpi", "DPI/0");
@@ -96,7 +96,7 @@ void GraphvizGraph::addNode(const char* name, int width, int height)
}
-void Autolayout::GraphvizGraph::setCompressShapes( bool b )
+void Autotqlayout::GraphvizGraph::setCompressShapes( bool b )
{
if (empty())
{
@@ -105,7 +105,7 @@ void Autolayout::GraphvizGraph::setCompressShapes( bool b )
}
}
-void Autolayout::GraphvizGraph::setCenterDiagram( bool b )
+void Autotqlayout::GraphvizGraph::setCenterDiagram( bool b )
{
if (empty())
{
@@ -114,7 +114,7 @@ void Autolayout::GraphvizGraph::setCenterDiagram( bool b )
}
}
-void Autolayout::GraphvizGraph::setShapeSeparation( int i )
+void Autotqlayout::GraphvizGraph::setShapeSeparation( int i )
{
char* a;
asprintf(&a,"%f",((float) i)/10.0);
@@ -122,22 +122,22 @@ void Autolayout::GraphvizGraph::setShapeSeparation( int i )
free (a);
}
-bool Autolayout::GraphvizGraph::empty( )
+bool Autotqlayout::GraphvizGraph::empty( )
{
return empty_flag;
}
-Autolayout::Node* Autolayout::GraphvizGraph::getNode( const char * arg1 )
+Autotqlayout::Node* Autotqlayout::GraphvizGraph::getNode( const char * arg1 )
{
char *a = _strcpy(arg1);
- Autolayout::GraphvizNode* b=
- new Autolayout::GraphvizNode(agnode(_agraph,a));
+ Autotqlayout::GraphvizNode* b=
+ new Autotqlayout::GraphvizNode(agnode(_agraph,a));
delete[](a);
nodelist.push_back(b);
return b;
}
-void GraphvizGraph::setCanvas( Autolayout::Canvas * canvas)
+void GraphvizGraph::setCanvas( Autotqlayout::Canvas * canvas)
{
char buf[100];
sprintf(buf,"%f,%f",((float)canvas->getMaxX()/DPI),((float)canvas->getMaxY()/DPI));
@@ -146,5 +146,5 @@ void GraphvizGraph::setCanvas( Autolayout::Canvas * canvas)
agraphattr(_agraph, "page", buf);
}
-} // end namespace Autolayout
+} // end namespace Autotqlayout